# Change Log

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/)
and this project adheres to [Semantic Versioning](http://semver.org/).

## [0.1.7] - 2020-06-11
### Changed
- Menu icon updated to FontAwesome v5, which allianceauth uses since 2.7.2

## [0.1.6] - 2020-06-09
### Changed
- Readme updated
- Prepared to be served via Pypi

## [0.1.5] - 2020-05-17
### Added
- Set up your own additional time zone panels via `local.py` (see readme)

## [0.1.4] - 2020-05-16
### Changed
- Button labels to better reflect what they are doing
- Month numbers into names in Adjust Time section
- Adjust time buttons are now a bit larger
- Order of information in the time zone panels

## [0.1.3] - 2020-05-15
### Added
- UTC offset

### Updated
- moment.js and timeago.js to their latest versions

## [0.1.2] - 2020-05-15
### Changed
- TZ panels now have their own template
- Chinese TZ panel now has also Russia / Siberia

## [0.1.1] - 2020-05-14
### Fixed
- Bootstrap template hierarchy

## [0.1.0] - 2020-05-14
### Added
- initial version
